#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 retrie
version:              1.2.3
visibility:           public
id:                   retrie-1.2.3-HF0vwFpgJfZGRvVdClNJd7
key:                  retrie-1.2.3-HF0vwFpgJfZGRvVdClNJd7
license:              MIT
copyright:            Copyright (c) Facebook, Inc. and its affiliates.
maintainer:           Andrew Farmer <anfarmer@fb.com>
author:               Andrew Farmer <anfarmer@fb.com>
homepage:             https://github.com/facebookincubator/retrie
synopsis:             A powerful, easy-to-use codemodding tool for Haskell.
description:
    Retrie is a tool for codemodding Haskell. Key goals include:

    * Speed: Efficiently rewrite in large (>1 million line) codebases.
    * Safety: Avoids large classes of codemod-related errors.
    * Ease-of-use: Haskell syntax instead of regular expressions. No hand-rolled AST traversals.

    This package provides a command-line tool (@retrie@) and a library
    ("Retrie") for making equational edits to Haskell code.

    Please see the [README](#readme) for examples and usage.

category:             Development
abi:                  65ed445dfec937f87461c5e269630817
exposed:              True
exposed-modules:
    Retrie Retrie.AlphaEnv Retrie.CPP Retrie.Context Retrie.Debug
    Retrie.Elaborate Retrie.ExactPrint Retrie.ExactPrint.Annotated
    Retrie.Expr Retrie.Fixity Retrie.FreeVars Retrie.GHC
    Retrie.GroundTerms Retrie.Monad Retrie.Options
    Retrie.PatternMap.Bag Retrie.PatternMap.Class
    Retrie.PatternMap.Instances Retrie.Pretty Retrie.Quantifiers
    Retrie.Query Retrie.Replace Retrie.Rewrites
    Retrie.Rewrites.Function Retrie.Rewrites.Patterns
    Retrie.Rewrites.Rules Retrie.Rewrites.Types Retrie.Run Retrie.SYB
    Retrie.Subst Retrie.Substitution Retrie.Types Retrie.Universe
    Retrie.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/retrie-1.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/retrie-1.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/retrie-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retrie
hs-libraries:         HSretrie-1.2.3-HF0vwFpgJfZGRvVdClNJd7
depends:
    ansi-terminal-1.1-EWnhDZJXy1I5W5pwBR2UDi
    async-2.2.6-1uwD9YLU3T8L6PSEM5z6Gb base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    filepath-1.4.300.1 ghc-9.6.6
    ghc-exactprint-1.7.1.0-EzYZZQxU9PGGhNDkq7zQqY
    list-t-1.0.5.7-HUolN9lPelH59LXN2KCa3E mtl-2.3.1
    optparse-applicative-0.18.1.0-Drsi2gM4wlG4ppHqpHKUIr
    process-1.6.19.0 random-shuffle-0.0.4-CVuy67R8xGI8cKE9l12hjD
    syb-0.7.3-45RHZbqQsU9HukQlnlXSjw text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-HCJacsgu3yzJSt2gCXir1U

haddock-interfaces:   /usr/share/doc/haskell-retrie/html/retrie.haddock
haddock-html:         /usr/share/doc/haskell-retrie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

